@@ -413,10 +413,13 @@ StatusDisplayer *statusDisplayerGlobal;
 
 - (NSMutableArray *)tracks
 {
+	NSLog(@"entering [NJB tracks]");
+	
 	if (![self isConnected])
 		return nil;
 	if (cachedTrackList)
 	{
+		NSLog(@"[NJB tracks] returning cachedTrackList");
 		return [self cachedTrackList];
 	}
 	
@@ -600,6 +603,9 @@ StatusDisplayer *statusDisplayerGlobal;
 	}
 	
 	downloadingTracks = NO;
+	
+	NSLog(@"leaving [NJB tracks]");
+	
 	return [self cachedTrackList];
 }
 
@@ -607,6 +613,7 @@ StatusDisplayer *statusDisplayerGlobal;
  */
 - (NJBTransactionResult *)uploadTrack:(Track *)track
 {
+	NSLog(@"uploading track");
 	if (![self isConnected])
 		return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:NSLocalizedString(@"Not connected", nil)] autorelease];
 	
