@@ -74,6 +74,7 @@ typedef enum {
   LIBMTP_FILETYPE_WINEXEC,
   LIBMTP_FILETYPE_TEXT,
   LIBMTP_FILETYPE_HTML,
+  LIBMTP_FILETYPE_FIRMWARE,
   LIBMTP_FILETYPE_UNKNOWN
 } LIBMTP_filetype_t;
 typedef struct LIBMTP_device_entry_struct LIBMTP_device_entry_t; /**< @see LIBMTP_device_entry_struct */
@@ -85,6 +86,7 @@ typedef struct LIBMTP_album_struct LIBMTP_album_t; /**< @see LIBMTP_album_struct
 typedef struct LIBMTP_folder_struct LIBMTP_folder_t; /**< @see LIBMTP_folder_t */
 typedef struct LIBMTP_object_struct LIBMTP_object_t; /**< @see LIBMTP_object_t */
 typedef struct LIBMTP_filesampledata_struct LIBMTP_filesampledata_t; /**< @see LIBMTP_filesample_t */
+typedef struct LIBMTP_devicestorage_struct LIBMTP_devicestorage_t; /**< @see LIBMTP_devicestorage_t */
 
 /**
  * The callback type definition. Notice that a progress percentage ratio
@@ -131,8 +133,12 @@ struct LIBMTP_mtpdevice_struct {
    * \c (PTP_USB*) before internal use.
    */
   void *usbinfo;
-  /** The storage ID for this device */
-  uint32_t storage_id;
+  /** 
+   * The storage for this device, do not use strings in here without 
+   * copying them first, and beware that this list may be rebuilt at
+   * any time.
+   */
+  LIBMTP_devicestorage_t *storage;
   /** The maximum battery level for this device */
   uint8_t maximum_battery_level;
   /** Default music folder */
@@ -149,6 +155,8 @@ struct LIBMTP_mtpdevice_struct {
   uint32_t default_zencast_folder;
   /** Default Album folder */
   uint32_t default_album_folder;
+  /** Default Text folder */
+  uint32_t default_text_folder;
   /** Per device iconv() converters, only used internally */
   void *cd;
 };
@@ -236,6 +244,24 @@ struct LIBMTP_filesampledata_struct {
   char *data; /**< Sample data */
 };
 
+/**
+ * LIBMTP Device Storage structure
+ */
+struct LIBMTP_devicestorage_struct {
+  uint32_t id; /**< Unique ID for this storage */
+  uint16_t StorageType; /**< Storage type */
+  uint16_t FilesystemType; /**< Filesystem type */
+  uint16_t AccessCapability; /**< Access capability */
+  uint64_t MaxCapacity; /**< Maximum capability */
+  uint64_t FreeSpaceInBytes; /**< Free space in bytes */
+  uint64_t FreeSpaceInObjects; /**< Free space in objects */
+  char *StorageDescription; /**< A brief description of this storage */
+  char *VolumeIdentifier; /**< A volume identifier */
+  LIBMTP_devicestorage_t *next; /**< Next storage, follow this link until NULL */
+  LIBMTP_devicestorage_t *prev; /**< Previous storage */
+};
+  
+
 /** @} */
 
 /* Make functions available for C++ */
@@ -265,10 +291,6 @@ char *LIBMTP_Get_Friendlyname(LIBMTP_mtpdevice_t*);
 int LIBMTP_Set_Friendlyname(LIBMTP_mtpdevice_t*, char const * const);
 char *LIBMTP_Get_Syncpartner(LIBMTP_mtpdevice_t*);
 int LIBMTP_Set_Syncpartner(LIBMTP_mtpdevice_t*, char const * const);
-int LIBMTP_Get_Storageinfo(LIBMTP_mtpdevice_t *, uint64_t * const,
-			uint64_t * const, char ** const storage_description,
-			char ** const volume_label);
-int LIBMTP_Format_Storage(LIBMTP_mtpdevice_t *);
 int LIBMTP_Get_Batterylevel(LIBMTP_mtpdevice_t *,
 			    uint8_t * const,
 			    uint8_t * const);
@@ -276,6 +298,14 @@ int LIBMTP_Get_Secure_Time(LIBMTP_mtpdevice_t *, char ** const);
 int LIBMTP_Get_Device_Certificate(LIBMTP_mtpdevice_t *, char ** const);
 int LIBMTP_Get_Supported_Filetypes(LIBMTP_mtpdevice_t *, uint16_t ** const, uint16_t * const);
 
+#define LIBMTP_STORAGE_SORTBY_NOTSORTED 0
+#define LIBMTP_STORAGE_SORTBY_FREESPACE 1
+#define LIBMTP_STORAGE_SORTBY_MAXSPACE  2
+
+int LIBMTP_Get_Storage(LIBMTP_mtpdevice_t *, int const);
+int LIBMTP_Format_Storage(LIBMTP_mtpdevice_t *, LIBMTP_devicestorage_t *);
+
+
 /**
  * @}
  * @defgroup files The file management API.
