@@ -134,20 +134,26 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   /*
    * iRiver
    * we assume that PTP_OC_MTP_GetObjPropList is essentially
-   * broken on all iRiver devices. Please test on your device
-   * if you believe it isn't!
+   * broken on all iRiver devices, meaning it simply won't return
+   * all properties for a file when asking for metadata 0xffffffff. 
+   * Please test on your device if you believe it isn't broken!
+   * Some devices from http://www.mtp-ums.net/viewdeviceinfo.php
    */
   { "iRiver Portable Media Center", 0x1006, 0x4002, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   { "iRiver Portable Media Center", 0x1006, 0x4003, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // From libgphoto2 source
   { "iRiver T10", 0x4102, 0x1113, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   { "iRiver T20 FM", 0x4102, 0x1114, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  // This appears at the MTP-UMS site
+  { "iRiver T20", 0x4102, 0x1115, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   { "iRiver U10", 0x4102, 0x1116, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   { "iRiver T10", 0x4102, 0x1117, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   { "iRiver T20", 0x4102, 0x1118, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   { "iRiver T30", 0x4102, 0x1119, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // Reported by David Wolpoff
   { "iRiver T10 2GB", 0x4102, 0x1120, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  // Rough guess this is the MTP device ID...
+  { "iRiver N12", 0x4102, 0x1122, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // Reported by Adam Torgerson
   { "iRiver Clix", 0x4102, 0x112a, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // Reported by Scott Call
@@ -168,7 +174,7 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   { "Toshiba Gigabeat S", 0x0930, 0x0010, DEVICE_FLAG_NONE },
   // Reported by Rob Brown
   { "Toshiba Gigabeat P10", 0x0930, 0x0011, DEVICE_FLAG_NONE },
-
+  
   /*
    * Archos
    */
@@ -194,7 +200,14 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   /*
    * Sirius
    */
-  { "Sirius Stiletto", 0x18f6, 0x0102, DEVICE_FLAG_NONE }
+  { "Sirius Stiletto", 0x18f6, 0x0102, DEVICE_FLAG_NONE },
+
+  /*
+   * Canon
+   * This is actually a camera, but it has a Microsoft device descriptor
+   * and reports itself as supporting the MTP extension.
+   */
+  {"Canon PowerShot A640 (PTP/MTP mode)", 0x04a9, 0x3139, DEVICE_FLAG_NONE }
   
 };
 static const int mtp_device_table_size = sizeof(mtp_device_table) / sizeof(LIBMTP_device_entry_t);
